summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/smpppdcs/smpppdsearcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/smpppdcs/smpppdsearcher.h')
-rw-r--r--kopete/plugins/smpppdcs/smpppdsearcher.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/plugins/smpppdcs/smpppdsearcher.h b/kopete/plugins/smpppdcs/smpppdsearcher.h
index 1e96f737..e5bb05a1 100644
--- a/kopete/plugins/smpppdcs/smpppdsearcher.h
+++ b/kopete/plugins/smpppdcs/smpppdsearcher.h
@@ -60,13 +60,13 @@ protected:
* @brief Scans a network for a smpppd
*
* Scans a network for a smpppd described by
- * ip and tqmask.
+ * ip and mask.
*
* @param ip the ntwork ip
* @param tqmask the network tqmask
* @return <code>TRUE</code> if an smpppd was found
*/
- bool scan(const TQString& ip, const TQString& tqmask);
+ bool scan(const TQString& ip, const TQString& mask);
signals:
/**
@@ -60,13 +60,13 @@ protected:
*
* @param ip the ntwork ip
- * @param tqmask the network tqmask
+ * @param mask the network mask
* @return <code>TRUE</code> if an smpppd was found
*/